@@ -19,6 +19,9 @@ from neutron_lib.api.definitions import allowedaddresspairs
 from neutron_lib.api.definitions import auto_allocated_topology
 from neutron_lib.api.definitions import availability_zone
 from neutron_lib.api.definitions import availability_zone_filter
+from neutron_lib.api.definitions import bgp
+from neutron_lib.api.definitions import bgp_4byte_asn
+from neutron_lib.api.definitions import bgp_dragentscheduler
 from neutron_lib.api.definitions import bgpvpn
 from neutron_lib.api.definitions import bgpvpn_routes_control
 from neutron_lib.api.definitions import bgpvpn_stdattrs
@@ -33,6 +36,7 @@ from neutron_lib.api.definitions import dns
 from neutron_lib.api.definitions import dns_domain_keywords
 from neutron_lib.api.definitions import dns_domain_ports
 from neutron_lib.api.definitions import dvr
+from neutron_lib.api.definitions import ecmp_routes
 from neutron_lib.api.definitions import empty_string_filtering
 from neutron_lib.api.definitions import expose_l3_conntrack_helper
 from neutron_lib.api.definitions import expose_port_forwarding_in_fip
@@ -43,6 +47,8 @@ from neutron_lib.api.definitions import extraroute_atomic
 from neutron_lib.api.definitions import filter_validation
 from neutron_lib.api.definitions import fip64
 from neutron_lib.api.definitions import fip_pf_description
+from neutron_lib.api.definitions import fip_pf_detail
+from neutron_lib.api.definitions import fip_pf_port_range
 from neutron_lib.api.definitions import fip_port_details
 from neutron_lib.api.definitions import firewall_v2
 from neutron_lib.api.definitions import flavors
@@ -57,8 +63,11 @@ from neutron_lib.api.definitions import l3
 from neutron_lib.api.definitions import l3_conntrack_helper
 from neutron_lib.api.definitions import l3_ext_gw_mode
 from neutron_lib.api.definitions import l3_ext_ha_mode
+from neutron_lib.api.definitions import l3_ext_ndp_proxy
 from neutron_lib.api.definitions import l3_flavors
+from neutron_lib.api.definitions import l3_ndp_proxy
 from neutron_lib.api.definitions import l3_port_ip_change_not_allowed
+from neutron_lib.api.definitions import local_ip
 from neutron_lib.api.definitions import logging
 from neutron_lib.api.definitions import logging_resource
 from neutron_lib.api.definitions import metering
@@ -66,15 +75,19 @@ from neutron_lib.api.definitions import metering_source_and_destination_filters
 from neutron_lib.api.definitions import multiprovidernet
 from neutron_lib.api.definitions import network
 from neutron_lib.api.definitions import network_availability_zone
+from neutron_lib.api.definitions import network_cascade_delete
 from neutron_lib.api.definitions import network_ip_availability
 from neutron_lib.api.definitions import network_mtu
 from neutron_lib.api.definitions import network_mtu_writable
 from neutron_lib.api.definitions import network_segment_range
 from neutron_lib.api.definitions import pagination
 from neutron_lib.api.definitions import port
+from neutron_lib.api.definitions import port_device_profile
+from neutron_lib.api.definitions import port_mac_address_override
 from neutron_lib.api.definitions import port_mac_address_regenerate
 from neutron_lib.api.definitions import port_numa_affinity_policy
 from neutron_lib.api.definitions import port_resource_request
+from neutron_lib.api.definitions import port_resource_request_groups
 from neutron_lib.api.definitions import port_security
 from neutron_lib.api.definitions import portbindings
 from neutron_lib.api.definitions import portbindings_extended
@@ -85,11 +98,20 @@ from neutron_lib.api.definitions import qos
 from neutron_lib.api.definitions import qos_bw_limit_direction
 from neutron_lib.api.definitions import qos_bw_minimum_ingress
 from neutron_lib.api.definitions import qos_default
+from neutron_lib.api.definitions import qos_fip
+from neutron_lib.api.definitions import qos_fip_network_policy
 from neutron_lib.api.definitions import qos_gateway_ip
 from neutron_lib.api.definitions import qos_port_network_policy
+from neutron_lib.api.definitions import qos_pps_minimum_rule
+from neutron_lib.api.definitions import qos_pps_minimum_rule_alias
+from neutron_lib.api.definitions import qos_pps_rule
 from neutron_lib.api.definitions import qos_rule_type_details
+from neutron_lib.api.definitions import qos_rule_type_filter
 from neutron_lib.api.definitions import qos_rules_alias
+from neutron_lib.api.definitions import quota_check_limit
+from neutron_lib.api.definitions import rbac_address_groups
 from neutron_lib.api.definitions import rbac_address_scope
+from neutron_lib.api.definitions import rbac_bgpvpn
 from neutron_lib.api.definitions import rbac_security_groups
 from neutron_lib.api.definitions import rbac_subnetpool
 from neutron_lib.api.definitions import revisionifmatch
@@ -100,6 +122,7 @@ from neutron_lib.api.definitions import routerservicetype
 from neutron_lib.api.definitions import security_groups_normalized_cidr
 from neutron_lib.api.definitions import security_groups_port_filtering
 from neutron_lib.api.definitions import security_groups_remote_address_group
+from neutron_lib.api.definitions import security_groups_shared_filtering
 from neutron_lib.api.definitions import segment
 from neutron_lib.api.definitions import segments_peer_subnet_host_routes
 from neutron_lib.api.definitions import servicetype
@@ -116,10 +139,12 @@ from neutron_lib.api.definitions import subnet_segmentid_writable
 from neutron_lib.api.definitions import subnet_service_types
 from neutron_lib.api.definitions import subnetpool
 from neutron_lib.api.definitions import subnetpool_prefix_ops
+from neutron_lib.api.definitions import taas
 from neutron_lib.api.definitions import tag_ports_during_bulk_creation
 from neutron_lib.api.definitions import trunk
 from neutron_lib.api.definitions import trunk_details
 from neutron_lib.api.definitions import uplink_status_propagation
+from neutron_lib.api.definitions import vlan_filter
 from neutron_lib.api.definitions import vlantransparent
 from neutron_lib.api.definitions import vpn
 from neutron_lib.api.definitions import vpn_endpoint_groups
@@ -136,6 +161,9 @@ _ALL_API_DEFINITIONS = {
     auto_allocated_topology,
     availability_zone,
     availability_zone_filter,
+    bgp,
+    bgp_4byte_asn,
+    bgp_dragentscheduler,
     bgpvpn,
     bgpvpn_routes_control,
     bgpvpn_stdattrs,
@@ -150,6 +178,7 @@ _ALL_API_DEFINITIONS = {
     dns_domain_keywords,
     dns_domain_ports,
     dvr,
+    ecmp_routes,
     empty_string_filtering,
     expose_l3_conntrack_helper,
     expose_port_forwarding_in_fip,
@@ -160,9 +189,11 @@ _ALL_API_DEFINITIONS = {
     filter_validation,
     fip64,
     firewall_v2,
+    fip_pf_detail,
     fip_port_details,
     flavors,
     floating_ip_port_forwarding,
+    fip_pf_port_range,
     fip_pf_description,
     floatingip_autodelete_internal,
     floatingip_pools,
@@ -174,8 +205,11 @@ _ALL_API_DEFINITIONS = {
     l3_conntrack_helper,
     l3_ext_gw_mode,
     l3_ext_ha_mode,
+    l3_ext_ndp_proxy,
     l3_flavors,
+    l3_ndp_proxy,
     l3_port_ip_change_not_allowed,
+    local_ip,
     logging,
     logging_resource,
     metering,
@@ -183,15 +217,19 @@ _ALL_API_DEFINITIONS = {
     multiprovidernet,
     network,
     network_availability_zone,
+    network_cascade_delete,
     network_ip_availability,
     network_mtu,
     network_mtu_writable,
     network_segment_range,
     pagination,
     port,
+    port_device_profile,
+    port_mac_address_override,
     port_mac_address_regenerate,
     port_numa_affinity_policy,
     port_resource_request,
+    port_resource_request_groups,
     port_security,
     portbindings,
     portbindings_extended,
@@ -202,11 +240,20 @@ _ALL_API_DEFINITIONS = {
     qos_bw_limit_direction,
     qos_bw_minimum_ingress,
     qos_default,
+    qos_fip,
+    qos_fip_network_policy,
     qos_gateway_ip,
     qos_port_network_policy,
+    qos_pps_minimum_rule,
+    qos_pps_minimum_rule_alias,
+    qos_pps_rule,
     qos_rule_type_details,
+    qos_rule_type_filter,
     qos_rules_alias,
+    quota_check_limit,
+    rbac_address_groups,
     rbac_address_scope,
+    rbac_bgpvpn,
     rbac_security_groups,
     rbac_subnetpool,
     revisionifmatch,
@@ -217,6 +264,7 @@ _ALL_API_DEFINITIONS = {
     security_groups_normalized_cidr,
     security_groups_port_filtering,
     security_groups_remote_address_group,
+    security_groups_shared_filtering,
     segment,
     segments_peer_subnet_host_routes,
     servicetype,
@@ -233,10 +281,12 @@ _ALL_API_DEFINITIONS = {
     subnet_service_types,
     subnetpool,
     subnetpool_prefix_ops,
+    taas,
     tag_ports_during_bulk_creation,
     trunk,
     trunk_details,
     uplink_status_propagation,
+    vlan_filter,
     vlantransparent,
     vpn,
     vpn_endpoint_groups,
