@@ -51,11 +51,12 @@ def _verify_dict_keys(expected_keys, target_dict, strict=True):
         message indicating why the validation failed.
     """
     if not isinstance(target_dict, dict):
-        msg = (_("Invalid input. '%(target_dict)s' must be a dictionary "
-                 "with keys: %(expected_keys)s") %
-               {'target_dict': target_dict, 'expected_keys': expected_keys})
-        LOG.debug(msg)
-        return msg
+        msg_data = {'target_dict': target_dict,
+                    'expected_keys': expected_keys}
+        msg = ("Invalid input. '%(target_dict)s' must be a dictionary "
+               "with keys: %(expected_keys)s")
+        LOG.debug(msg, msg_data)
+        return _(msg) % msg_data
 
     expected_keys = set(expected_keys)
     provided_keys = set(target_dict.keys())
@@ -63,13 +64,13 @@ def _verify_dict_keys(expected_keys, target_dict, strict=True):
     predicate = expected_keys.__eq__ if strict else expected_keys.issubset
 
     if not predicate(provided_keys):
-        msg = (_("Validation of dictionary's keys failed. "
-                 "Expected keys: %(expected_keys)s "
-                 "Provided keys: %(provided_keys)s") %
-               {'expected_keys': expected_keys,
-                'provided_keys': provided_keys})
-        LOG.debug(msg)
-        return msg
+        msg_data = {'expected_keys': expected_keys,
+                    'provided_keys': provided_keys}
+        msg = ("Validation of dictionary's keys failed. "
+               "Expected keys: %(expected_keys)s "
+               "Provided keys: %(provided_keys)s")
+        LOG.debug(msg, msg_data)
+        return _(msg) % msg_data
 
 
 def _collect_duplicates(data_list):
@@ -77,14 +78,14 @@ def _collect_duplicates(data_list):
 
     :param data_list: A list of items to check for duplicates. The list may
         include dict items.
-    :returns: A set of items that are duplicates in data_list. If no
-        duplicates are found, the returned set is empty.
+    :returns: A list of items that are duplicates in data_list. If no
+        duplicates are found, the returned list is empty.
     """
     seen = []
-    dups = set()
+    dups = []
     for datum in data_list:
-        if datum in seen:
-            dups.add(datum)
+        if datum in seen and datum not in dups:
+            dups.append(datum)
             continue
         seen.append(datum)
     return dups
@@ -158,18 +159,19 @@ def validate_values(data, valid_values=None, valid_values_display=None):
         try:
             if data not in valid_values:
                 valid_values_display = valid_values_display or 'valid_values'
-                msg = (_("%(data)s is not in %(valid_values)s") %
-                       {'data': data, 'valid_values': valid_values_display})
-                LOG.debug(msg)
-                return msg
-        except TypeError:
+                msg_data = {'data': data,
+                            'valid_values': valid_values_display}
+                msg = "%(data)s is not in %(valid_values)s"
+                LOG.debug(msg, msg_data)
+                return _(msg) % msg_data
+        except TypeError as e:
             # This is a programming error
             msg = (_("'data' of type '%(typedata)s' and 'valid_values' "
                      "of type '%(typevalues)s' are not "
                      "compatible for comparison") %
                    {'typedata': type(data),
                     'typevalues': type(valid_values)})
-            raise TypeError(msg)
+            raise TypeError(msg) from e
     else:
         # This is a programming error
         msg = (_("'valid_values' does not support membership operations"))
@@ -201,9 +203,9 @@ def validate_not_empty_string(data, max_len=None):
     if msg:
         return msg
     if not data.strip():
-        msg = _("'%s' Blank strings are not permitted") % data
-        LOG.debug(msg)
-        return msg
+        msg = "'%s' Blank strings are not permitted"
+        LOG.debug(msg, data)
+        return _(msg) % data
 
 
 def validate_string_or_none(data, max_len=None):
@@ -228,15 +230,15 @@ def validate_string(data, max_len=None):
         the data is invalid.
     """
     if not isinstance(data, str):
-        msg = _("'%s' is not a valid string") % data
-        LOG.debug(msg)
-        return msg
+        msg = "'%s' is not a valid string"
+        LOG.debug(msg, data)
+        return _(msg) % data
 
     if max_len is not None and len(data) > max_len:
-        msg = (_("'%(data)s' exceeds maximum length of %(max_len)s") %
-               {'data': data, 'max_len': max_len})
-        LOG.debug(msg)
-        return msg
+        msg_data = {'data': data, 'max_len': max_len}
+        msg = "'%(data)s' exceeds maximum length of %(max_len)s"
+        LOG.debug(msg, msg_data)
+        return _(msg) % msg_data
 
 
 _validate_list_of_unique_strings = functools.partial(_validate_list_of_items,
@@ -255,6 +257,36 @@ def validate_list_of_unique_strings(data, max_len=None):
     return _validate_list_of_unique_strings(data, max_len=max_len)
 
 
+def validate_oneline_not_empty_string(data, max_len=None):
+    """Validate data is a non-empty string without newline character.
+
+    :param data: The data to validate.
+    :param max_len: An optional cap on the length of the string.
+    :returns: None if the data is a string without newline character,
+        otherwise a human readable message indicating why validation failed.
+    """
+    msg = validate_not_empty_string(data, max_len=max_len)
+    if msg:
+        return msg
+    if len(data.splitlines()) > 1:
+        msg = "Multi-line string is not allowed: '%s'"
+        LOG.debug(msg, data)
+        return _(msg) % data
+
+
+def validate_oneline_not_empty_string_or_none(data, max_len=None):
+    """Validate data is a non-empty string without newline character or None.
+
+    :param data: The data to validate.
+    :param max_len: An optional cap on the length of the string data.
+    :returns: None if the data is None or a valid string without newline
+        character, otherwise a human readable message indicating why
+        validation failed.
+    """
+    if data is not None:
+        return validate_oneline_not_empty_string(data, max_len=max_len)
+
+
 def validate_boolean(data, valid_values=None):
     """Validate data is a python bool compatible object.
 
@@ -266,9 +298,9 @@ def validate_boolean(data, valid_values=None):
     try:
         strutils.bool_from_string(data, strict=True)
     except ValueError:
-        msg = _("'%s' is not a valid boolean value") % data
-        LOG.debug(msg)
-        return msg
+        msg = "'%s' is not a valid boolean value"
+        LOG.debug(msg, data)
+        return _(msg) % data
 
 
 def validate_integer(data, valid_values=None):
@@ -288,22 +320,22 @@ def validate_integer(data, valid_values=None):
         if msg:
             return msg
 
-    msg = _("'%s' is not an integer") % data
+    msg = "'%s' is not an integer"
     try:
         fl_n = float(data)
         int_n = int(data)
     except (ValueError, TypeError, OverflowError):
-        LOG.debug(msg)
-        return msg
+        LOG.debug(msg, data)
+        return _(msg) % data
 
     # Fail test if non equal or boolean
     if fl_n != int_n:
         LOG.debug(msg)
-        return msg
+        return _(msg) % data
     elif isinstance(data, bool):
-        msg = _("'%s' is not an integer:boolean") % data
-        LOG.debug(msg)
-        return msg
+        msg = "'%s' is not an integer:boolean"
+        LOG.debug(msg, data)
+        return _(msg) % data
 
 
 def validate_range(data, valid_values=None):
@@ -326,19 +358,19 @@ def validate_range(data, valid_values=None):
     try:
         data = int(data)
     except (ValueError, TypeError):
-        msg = _("'%s' is not an integer") % data
-        LOG.debug(msg)
-        return msg
+        msg = "'%s' is not an integer"
+        LOG.debug(msg, data)
+        return _(msg) % data
     if min_value is not UNLIMITED and data < min_value:
-        msg = _("'%(data)s' is too small - must be at least "
-                "'%(limit)d'") % {'data': data, 'limit': min_value}
-        LOG.debug(msg)
-        return msg
+        msg_data = {'data': data, 'limit': min_value}
+        msg = "'%(data)s' is too small - must be at least '%(limit)d'"
+        LOG.debug(msg, msg_data)
+        return _(msg) % msg_data
     if max_value is not UNLIMITED and data > max_value:
-        msg = _("'%(data)s' is too large - must be no larger than "
-                "'%(limit)d'") % {'data': data, 'limit': max_value}
-        LOG.debug(msg)
-        return msg
+        msg_data = {'data': data, 'limit': max_value}
+        msg = "'%(data)s' is too large - must be no larger than '%(limit)d'"
+        LOG.debug(msg, msg_data)
+        return _(msg) % msg_data
 
 
 def validate_range_or_none(data, valid_values=None):
@@ -357,9 +389,9 @@ def validate_no_whitespace(data):
     :raises InvalidInput: If the data contains whitespace.
     """
     if re.search(r'\s', data):
-        msg = _("'%s' contains whitespace") % data
-        LOG.debug(msg)
-        raise n_exc.InvalidInput(error_message=msg)
+        msg = "'%s' contains whitespace"
+        LOG.debug(msg, data)
+        raise n_exc.InvalidInput(error_message=_(msg) % data)
     return data
 
 
@@ -377,15 +409,15 @@ def validate_mac_address(data, valid_values=None):
         valid_mac = False
 
     if valid_mac:
-        valid_mac = (not netaddr.EUI(data) in
+        valid_mac = (netaddr.EUI(data) not in
                      map(netaddr.EUI, constants.INVALID_MAC_ADDRESSES))
     # TODO(arosen): The code in this file should be refactored
     # so it catches the correct exceptions. validate_no_whitespace
     # raises AttributeError if data is None.
     if not valid_mac:
-        msg = _("'%s' is not a valid MAC address") % data
-        LOG.debug(msg)
-        return msg
+        msg = "'%s' is not a valid MAC address"
+        LOG.debug(msg, data)
+        return _(msg) % data
 
 
 def validate_mac_address_or_none(data, valid_values=None):
@@ -409,6 +441,7 @@ def validate_ip_address(data, valid_values=None):
         message indicating why data isn't an IP address.
     """
     msg = None
+    msg_data = data
     try:
         # netaddr.core.ZEROFILL is only applicable to IPv4.
         # it will remove leading zeros from IPv4 address octets.
@@ -428,18 +461,20 @@ def validate_ip_address(data, valid_values=None):
         #   IPAddress('199.28.113.199')
         #   >>>
         if ':' not in data and data.count('.') != 3:
-            msg = _("'%s' is not a valid IP address") % data
+            msg = "'%s' is not a valid IP address"
         # A leading '0' in IPv4 address may be interpreted as an octal number,
         # e.g. 011 octal is 9 decimal. Since there is no standard saying
         # whether IP address with leading '0's should be interpreted as octal
         # or decimal, hence we reject leading '0's to avoid ambiguity.
         elif ip.version == 4 and str(ip) != data:
-            msg = _("'%(data)s' is not an accepted IP address, "
-                    "'%(ip)s' is recommended") % {"data": data, "ip": ip}
+            msg_data = {"data": data, "ip": ip}
+            msg = ("'%(data)s' is not an accepted IP address, "
+                   "'%(ip)s' is recommended")
     except Exception:
-        msg = _("'%s' is not a valid IP address") % data
+        msg = "'%s' is not a valid IP address"
     if msg:
-        LOG.debug(msg)
+        LOG.debug(msg, msg_data)
+        msg = _(msg) % msg_data
     return msg
 
 
@@ -456,9 +491,9 @@ def _validate_any_key_spec(data, key_specs=None):
     for spec in key_specs:
         if validate_dict(data, spec) is None:
             return None
-    msg = _("No valid key specs matched for: %s") % data
-    LOG.debug(msg)
-    return msg
+    msg = "No valid key specs matched for: %s"
+    LOG.debug(msg, data)
+    return _(msg) % data
 
 
 def validate_any_key_specs_or_none(data, key_specs=None):
@@ -496,9 +531,9 @@ def validate_ip_pools(data, valid_values=None):
         indicating why the data is invalid.
     """
     if not isinstance(data, list):
-        msg = _("Invalid data format for IP pool: '%s'") % data
-        LOG.debug(msg)
-        return msg
+        msg = "Invalid data format for IP pool: '%s'"
+        LOG.debug(msg, data)
+        return _(msg) % data
 
     expected_keys = ['start', 'end']
     for ip_pool in data:
@@ -523,23 +558,24 @@ def validate_fixed_ips(data, valid_values=None):
         human readable message is returned indicating why validation failed.
     """
     if not isinstance(data, list):
-        msg = _("Invalid data format for fixed IP: '%s'") % data
-        LOG.debug(msg)
-        return msg
+        msg = "Invalid data format for fixed IP: '%s'"
+        LOG.debug(msg, data)
+        return _(msg) % data
 
     ips = []
     for fixed_ip in data:
         if not isinstance(fixed_ip, dict):
-            msg = _("Invalid data format for fixed IP: '%s'") % fixed_ip
-            LOG.debug(msg)
-            return msg
+            msg = "Invalid data format for fixed IP: '%s'"
+            LOG.debug(msg, fixed_ip)
+            return _(msg) % fixed_ip
         if 'ip_address' in fixed_ip:
             # Ensure that duplicate entries are not set - just checking IP
             # suffices. Duplicate subnet_id's are legitimate.
             fixed_ip_address = fixed_ip['ip_address']
             if fixed_ip_address in ips:
-                msg = _("Duplicate IP address '%s'") % fixed_ip_address
-                LOG.debug(msg)
+                msg = "Duplicate IP address '%s'"
+                LOG.debug(msg, fixed_ip_address)
+                msg = _(msg) % fixed_ip_address
             else:
                 msg = validate_ip_address(fixed_ip_address)
             if msg:
@@ -560,23 +596,23 @@ def validate_nameservers(data, valid_values=None):
         a human readable message is returned indicating why validation failed.
     """
     if not hasattr(data, '__iter__'):
-        msg = _("Invalid data format for nameserver: '%s'") % data
-        LOG.debug(msg)
-        return msg
+        msg = "Invalid data format for nameserver: '%s'"
+        LOG.debug(msg, data)
+        return _(msg) % data
 
     hosts = []
     for host in data:
         # This must be an IP address only
         msg = validate_ip_address(host)
         if msg:
-            msg = _("'%(host)s' is not a valid nameserver. %(msg)s") % {
-                'host': host, 'msg': msg}
-            LOG.debug(msg)
-            return msg
+            msg_data = {'host': host, 'msg': msg}
+            msg = "'%(host)s' is not a valid nameserver. %(msg)s"
+            LOG.debug(msg, msg_data)
+            return _(msg) % msg_data
         if host in hosts:
-            msg = _("Duplicate nameserver '%s'") % host
-            LOG.debug(msg)
-            return msg
+            msg = "Duplicate nameserver '%s'"
+            LOG.debug(msg, host)
+            return _(msg) % host
         hosts.append(host)
 
 
@@ -591,9 +627,9 @@ def validate_hostroutes(data, valid_values=None):
         otherwise a human readable message indicating why validation failed.
     """
     if not isinstance(data, list):
-        msg = _("Invalid data format for hostroute: '%s'") % data
-        LOG.debug(msg)
-        return msg
+        msg = "Invalid data format for hostroute: '%s'"
+        LOG.debug(msg, data)
+        return _(msg) % data
 
     expected_keys = ['destination', 'nexthop']
     hostroutes = []
@@ -608,9 +644,9 @@ def validate_hostroutes(data, valid_values=None):
         if msg:
             return msg
         if hostroute in hostroutes:
-            msg = _("Duplicate hostroute '%s'") % hostroute
-            LOG.debug(msg)
-            return msg
+            msg = "Duplicate hostroute '%s'"
+            LOG.debug(msg, hostroute)
+            return _(msg) % hostroute
         hostroutes.append(hostroute)
 
 
@@ -651,19 +687,20 @@ def validate_subnet(data, valid_values=None):
         readable message as to why data is invalid.
     """
     msg = None
+    msg_data = data
     try:
         net = netaddr.IPNetwork(validate_no_whitespace(data))
         if '/' not in data or (net.version == 4 and str(net) != data):
-            msg = _("'%(data)s' isn't a recognized IP subnet cidr,"
-                    " '%(cidr)s' is recommended") % {"data": data,
-                                                     "cidr": net.cidr}
+            msg_data = {"data": data, "cidr": net.cidr}
+            msg = ("'%(data)s' isn't a recognized IP subnet cidr,"
+                   " '%(cidr)s' is recommended")
         else:
             return
     except Exception:
-        msg = _("'%s' is not a valid IP subnet") % data
+        msg = "'%s' is not a valid IP subnet"
     if msg:
-        LOG.debug(msg)
-    return msg
+        LOG.debug(msg, msg_data)
+    return _(msg) % msg_data
 
 
 def validate_route_cidr(data, valid_values=None):
@@ -675,21 +712,22 @@ def validate_route_cidr(data, valid_values=None):
               readable message as to why data is invalid.
     """
     msg = None
+    msg_data = data
     try:
         net = netaddr.IPNetwork(validate_no_whitespace(data))
         if '/' not in data or (net.network != net.ip):
-            msg = _("'%(data)s' is not a recognized CIDR,"
-                    " '%(cidr)s' is recommended") % {"data": data,
-                                                     "cidr": net.cidr}
+            msg_data = {"data": data, "cidr": net.cidr}
+            msg = ("'%(data)s' is not a recognized CIDR,"
+                   " '%(cidr)s' is recommended")
         elif net.is_loopback():
-            msg = _("'%(data)s' is not a routable CIDR") % {"data": data}
+            msg = "'%s' is not a routable CIDR"
         else:
             return
     except Exception:
-        msg = _("'%s' is not a valid CIDR") % data
+        msg = "'%s' is not a valid CIDR"
     if msg:
-        LOG.debug(msg)
-    return msg
+        LOG.debug(msg, msg_data)
+    return _(msg) % msg_data
 
 
 def validate_subnet_or_none(data, valid_values=None):
@@ -747,9 +785,9 @@ def validate_regex(data, valid_values=None):
     except TypeError:
         pass
 
-    msg = _("'%s' is not a valid input") % data
-    LOG.debug(msg)
-    return msg
+    msg = "'%s' is not a valid input"
+    LOG.debug(msg, data)
+    return _(msg) % data
 
 
 def validate_regex_or_none(data, valid_values=None):
@@ -811,9 +849,9 @@ def validate_uuid(data, valid_values=None):
         message indicating why data is invalid.
     """
     if not uuidutils.is_uuid_like(data):
-        msg = _("'%s' is not a valid UUID") % data
-        LOG.debug(msg)
-        return msg
+        msg = "'%s' is not a valid UUID"
+        LOG.debug(msg, data)
+        return _(msg) % data
 
 
 def validate_uuid_or_none(data, valid_values=None):
@@ -868,8 +906,8 @@ def _extract_validator(key_validator):
                 return (validator_name,
                         validators[validator_name],
                         validator_params)
-            except KeyError:
-                raise UndefinedValidator(validator_name)
+            except KeyError as e:
+                raise UndefinedValidator(validator_name) from e
     return None, None, None
 
 
@@ -902,9 +940,9 @@ def validate_dict(data, key_specs=None):
         not valid.
     """
     if not isinstance(data, dict):
-        msg = _("'%s' is not a dictionary") % data
-        LOG.debug(msg)
-        return msg
+        msg = "'%s' is not a dictionary"
+        LOG.debug(msg, data)
+        return _(msg) % data
     # Do not perform any further validation, if no constraints are supplied
     if not key_specs:
         return
@@ -921,9 +959,10 @@ def validate_dict(data, key_specs=None):
     # Check whether unexpected keys are supplied in data
     unexpected_keys = [key for key in data if key not in key_specs]
     if unexpected_keys:
-        msg = _("Unexpected keys supplied: %s") % ', '.join(unexpected_keys)
-        LOG.debug(msg)
-        return msg
+        msg_data = ', '.join(unexpected_keys)
+        msg = "Unexpected keys supplied: %s"
+        LOG.debug(msg, msg_data)
+        return _(msg) % msg_data
 
     # Perform validation and conversion of all values
     # according to the specifications.
@@ -987,47 +1026,54 @@ def validate_non_negative(data, valid_values=None):
     try:
         data = int(data)
     except (ValueError, TypeError):
-        msg = _("'%s' is not an integer") % data
-        LOG.debug(msg)
-        return msg
+        msg = "'%s' is not an integer"
+        LOG.debug(msg, data)
+        return _(msg) % data
 
     if data < 0:
-        msg = _("'%s' should be non-negative") % data
-        LOG.debug(msg)
-        return msg
+        msg = "'%s' should be non-negative"
+        LOG.debug(msg, data)
+        return _(msg) % data
 
 
 def validate_port_range_or_none(data, valid_values=None):
     """Validate data is a range of TCP/UDP port numbers
 
     :param data: The data to validate
-    :param valid_values: Not used!
-    :returns: None if data is an int between 0 and 65535, or two ints between 0
-        and 65535 with a colon between them, otherwise a human readable message
-        as to why data is invalid.
+    :param valid_values: valid port range, default is [0, 65535]
+    :returns: None if data is a valid port between the values defined in the
+        valid_values param, or two valid ports between the values defined in
+        the valid_values param with a colon between them, otherwise a human
+        readable message as to why data is invalid.
     """
     if data is None:
         return
+
+    min_value, max_value = valid_values or [0, 65535]
+
     data = str(data)
     ports = data.split(':')
     if len(ports) > 2:
-        msg = _("Port range must be two integers separated by a colon")
+        msg = "Port range must be two integers separated by a colon"
         LOG.debug(msg)
-        return msg
+        return _(msg)
     for p in ports:
         if len(p) == 0:
-            msg = _("Port range must be two integers separated by a colon")
+            msg = "Port range must be two integers separated by a colon"
             LOG.debug(msg)
-            return msg
+            return _(msg)
         if not netutils.is_valid_port(p):
-            msg = _("Invalid port: %s") % p
-            LOG.debug(msg)
-            return msg
+            msg = "Invalid port: %s"
+            LOG.debug(msg, p)
+            return _(msg) % p
+        if max_value < int(p) or int(p) < min_value:
+            msg = "Invalid port: %s, the port must be in the range [%s, %s]"
+            LOG.debug(msg, p, min_value, max_value)
+            return _(msg) % (p, min_value, max_value)
     if len(ports) > 1 and int(ports[0]) > int(ports[1]):
-        msg = _("First port in a port range must be lower than the second "
-                "port")
+        msg = "First port in a port range must be lower than the second port"
         LOG.debug(msg)
-        return msg
+        return _(msg)
 
 
 def validate_subports(data, valid_values=None):
@@ -1040,24 +1086,23 @@ def validate_subports(data, valid_values=None):
         readable message is returned indicating why the data is invalid.
     """
     if not isinstance(data, list):
-        msg = _("Invalid data format for subports: '%s' is not a list") % data
-        LOG.debug(msg)
-        return msg
+        msg = "Invalid data format for subports: '%s' is not a list"
+        LOG.debug(msg, data)
+        return _(msg) % data
 
     subport_ids = set()
     segmentations = collections.defaultdict(set)
     for subport in data:
         if not isinstance(subport, dict):
-            msg = _("Invalid data format for subport: "
-                    "'%s' is not a dict") % subport
-            LOG.debug(msg)
-            return msg
+            msg = "Invalid data format for subport: '%s' is not a dict"
+            LOG.debug(msg, subport)
+            return _(msg) % subport
 
         # Expect a non duplicated and valid port_id for the subport
         if 'port_id' not in subport:
-            msg = _("A valid port UUID must be specified")
+            msg = "A valid port UUID must be specified"
             LOG.debug(msg)
-            return msg
+            return _(msg)
         elif validate_uuid(subport["port_id"]):
             msg = _("Invalid UUID for subport: '%s'") % subport["port_id"]
             return msg
@@ -1076,17 +1121,18 @@ def validate_subports(data, valid_values=None):
         segmentation_id = subport.get("segmentation_id")
         if ((not segmentation_type or segmentation_id is None) and
                 len(subport) > 1):
-            msg = _("Invalid subport details '%s': missing segmentation "
-                    "information. Must specify both segmentation_id and "
-                    "segmentation_type") % subport
-            LOG.debug(msg)
-            return msg
+            msg = ("Invalid subport details '%s': missing segmentation "
+                   "information. Must specify both segmentation_id and "
+                   "segmentation_type")
+            LOG.debug(msg, subport)
+            return _(msg) % subport
         if segmentation_id in segmentations.get(segmentation_type, []):
-            msg = _("Segmentation ID '%(seg_id)s' for '%(subport)s' is not "
-                    "unique") % {"seg_id": segmentation_id,
-                                 "subport": subport["port_id"]}
-            LOG.debug(msg)
-            return msg
+            msg_data = {"seg_id": segmentation_id,
+                        "subport": subport["port_id"]}
+            msg = ("Segmentation ID '%(seg_id)s' for '%(subport)s' is not "
+                   "unique")
+            LOG.debug(msg, msg_data)
+            return _(msg) % msg_data
         if segmentation_id is not None:
             segmentations[segmentation_type].add(segmentation_id)
 
@@ -1119,7 +1165,7 @@ def validate_subnet_service_types(service_types, valid_values=None):
             if not isinstance(service_type, str):
                 raise n_exc.InvalidInputSubnetServiceType(
                     service_type=service_type)
-            elif not service_type.startswith(tuple(prefixes)):
+            if not service_type.startswith(tuple(prefixes)):
                 raise n_exc.InvalidSubnetServiceType(service_type=service_type)
 
 
@@ -1141,8 +1187,7 @@ def validate_ethertype(ethertype, valid_values=None):
             if ethertype_str == "IPV4":
                 ethertype_str = "IP"
             ethertype_name = 'ETH_TYPE_' + ethertype_str
-            if ethertype_name in os_ken_ethertypes:
-                ethertype = os_ken_ethertypes[ethertype_name]
+            ethertype = os_ken_ethertypes.get(ethertype_name, ethertype)
         except TypeError:
             # Value of ethertype cannot be coerced into a string, like None
             pass
@@ -1150,24 +1195,24 @@ def validate_ethertype(ethertype, valid_values=None):
             if isinstance(ethertype, str):
                 ethertype = int(ethertype, 16)
             if (isinstance(ethertype, int) and
-                    constants.ETHERTYPE_MIN <= ethertype and
-                    ethertype <= constants.ETHERTYPE_MAX):
+                    constants.ETHERTYPE_MIN <= ethertype <=
+                    constants.ETHERTYPE_MAX):
                 return None
         except ValueError:
             pass
-        msg = _("Ethertype %s is not a two octet hexadecimal "
-                "number or ethertype name.") % ethertype
-        LOG.debug(msg)
-        return msg
+        msg = ("Ethertype %s is not a two octet hexadecimal "
+               "number or ethertype name.")
+        LOG.debug(msg, ethertype)
+        return _(msg) % ethertype
     else:
         if ethertype in constants.VALID_ETHERTYPES:
             return None
         valids = ','.join(map(str, constants.VALID_ETHERTYPES))
-        msg = _("Ethertype %(ethertype)s is not a valid ethertype, must be "
-                "one of %(valid_ethertypes)s.") % {'ethertype': ethertype,
-                                                   'valid_ethertypes': valids}
-        LOG.debug(msg)
-        return msg
+        msg_data = {'ethertype': ethertype, 'valid_ethertypes': valids}
+        msg = ("Ethertype %(ethertype)s is not a valid ethertype, must be "
+               "one of %(valid_ethertypes)s.")
+        LOG.debug(msg, msg_data)
+        return _(msg) % msg_data
 
 
 # Dictionary that maintains a list of validation functions
@@ -1197,6 +1242,10 @@ validators = {'type:dict': validate_dict,
               'type:not_empty_string': validate_not_empty_string,
               'type:not_empty_string_or_none':
               validate_not_empty_string_or_none,
+              'type:oneline_not_empty_string':
+              validate_oneline_not_empty_string,
+              'type:oneline_not_empty_string_or_none':
+              validate_oneline_not_empty_string_or_none,
               'type:subnet': validate_subnet,
               'type:subnet_list': validate_subnet_list,
               'type:subnet_or_none': validate_subnet_or_none,
