@@ -13,16 +13,16 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import mock
+from unittest import mock
+
 import netaddr
-import six
 import testtools
 
 from neutron_lib.api import converters
 from neutron_lib import constants
 from neutron_lib import exceptions as n_exc
 from neutron_lib.tests import _base as base
-from neutron_lib.tests import _tools as tools
+from neutron_lib.tests import tools
 
 
 class TestConvertToBoolean(base.BaseTestCase):
@@ -177,23 +177,23 @@ class TestConvertIPv6AddrCanonicalFormat(base.BaseTestCase):
 
     def test_convert_ipv6_address_extended_add_with_zeroes(self):
         result = converters.convert_ip_to_canonical_format(
-            u'2001:0db8:0:0:0:0:0:0001')
-        self.assertEqual(u'2001:db8::1', result)
+            '2001:0db8:0:0:0:0:0:0001')
+        self.assertEqual('2001:db8::1', result)
 
     @testtools.skipIf(tools.is_bsd(), 'bug/1484837')
     def test_convert_ipv6_compressed_address_OSX_skip(self):
         result = converters.convert_ip_to_canonical_format(
-            u'2001:db8:0:1:1:1:1:1')
-        self.assertEqual(u'2001:db8:0:1:1:1:1:1', result)
+            '2001:db8:0:1:1:1:1:1')
+        self.assertEqual('2001:db8:0:1:1:1:1:1', result)
 
     def test_convert_ipv6_extended_addr_to_compressed(self):
         result = converters.convert_ip_to_canonical_format(
             u"Fe80:0:0:0:0:0:0:1")
-        self.assertEqual(u'fe80::1', result)
+        self.assertEqual('fe80::1', result)
 
     def test_convert_ipv4_address(self):
         result = converters.convert_ip_to_canonical_format(u"192.168.1.1")
-        self.assertEqual(u'192.168.1.1', result)
+        self.assertEqual('192.168.1.1', result)
 
     def test_convert_None_address(self):
         result = converters.convert_ip_to_canonical_format(None)
@@ -202,30 +202,36 @@ class TestConvertIPv6AddrCanonicalFormat(base.BaseTestCase):
     def test_convert_invalid_address(self):
         result = converters.convert_ip_to_canonical_format("on")
         self.assertEqual("on", result)
+        result = converters.convert_ip_to_canonical_format(
+            '192.168.1.1/32')
+        self.assertEqual('192.168.1.1/32', result)
+        result = converters.convert_ip_to_canonical_format(
+            '2001:db8:0:1:1:1:1:1/128')
+        self.assertEqual('2001:db8:0:1:1:1:1:1/128', result)
 
 
 class TestConvertIPv6CIDRCanonicalFormat(base.BaseTestCase):
 
     def test_convert_ipv4_address_with_CIDR(self):
-        result = converters.convert_cidr_to_canonical_format(u'192.168.1.1/24')
-        self.assertEqual(u'192.168.1.1/24', result)
+        result = converters.convert_cidr_to_canonical_format('192.168.1.1/24')
+        self.assertEqual('192.168.1.1/24', result)
 
     def test_convert_ipv6_extended_addr_withcidr_to_compressed(self):
         result = converters.convert_cidr_to_canonical_format(
-            u'Fe80:0:0:0:0:0:0:1/64')
-        self.assertEqual(u'fe80::1/64', result)
+            'Fe80:0:0:0:0:0:0:1/64')
+        self.assertEqual('fe80::1/64', result)
 
     def test_convert_non_ip_addr_with_slash(self):
         with testtools.ExpectedException(n_exc.InvalidInput):
             converters.convert_cidr_to_canonical_format(
-                u"Dormamu/DarkSeid/Vulture")
+                "Dormamu/DarkSeid/Vulture")
 
 
 class TestConvertStringToCaseInsensitive(base.BaseTestCase):
 
     def test_convert_string_to_lower(self):
         result = converters.convert_string_to_case_insensitive(u"THIS Is tEsT")
-        self.assertIsInstance(result, six.string_types)
+        self.assertIsInstance(result, str)
 
     def test_assert_error_on_non_string(self):
         for invalid in [[], 123]:
@@ -347,3 +353,58 @@ class TestConvertPortMacAddress(base.BaseTestCase):
         CONF.base_mac = 'fa:16:3e:00:00:00'
         self.assertTrue(
             netaddr.valid_mac(converters.convert_to_mac_if_none(None)))
+
+
+class TestConvertToSanitizedMacAddress(base.BaseTestCase):
+
+    def test_sanitize_mac_address(self):
+        self.assertEqual(
+            '00:11:22:33:44:55',
+            converters.convert_to_sanitized_mac_address('00:11:22:33:44:55'))
+        self.assertEqual(
+            '00:11:22:33:44:05',
+            converters.convert_to_sanitized_mac_address('00:11:22:33:44:5'))
+        self.assertEqual(
+            '00:01:02:03:04:05',
+            converters.convert_to_sanitized_mac_address('0:1:2:3:4:5'))
+        self.assertEqual(
+            'ca:fe:ca:fe:0a:0e',
+            converters.convert_to_sanitized_mac_address('ca:FE:cA:Fe:a:E'))
+        self.assertEqual(
+            '01:23:45:67:89:01',
+            converters.convert_to_sanitized_mac_address('12345678901'))
+        self.assertEqual(
+            '01:23:45:67:89:01',
+            converters.convert_to_sanitized_mac_address('012345678901'))
+
+        # Not converted, those MAC address will fail in the validation step.
+        self.assertEqual(
+            '00:11:22:33:44',
+            converters.convert_to_sanitized_mac_address('00:11:22:33:44'))
+        self.assertEqual(
+            '00:11:22:33:44:',
+            converters.convert_to_sanitized_mac_address('00:11:22:33:44:'))
+
+
+class TestConvertToSanitizedBindingProfileAllocation(base.BaseTestCase):
+
+    RP_UUID = '41d7391e-1f69-11ec-a899-8f9d6d950f8d'
+    PORT_ID = '64d01804-1f83-11ec-987c-7f6caec3998b'
+    MIN_BW_RULE_ID = '52441596-1f83-11ec-93c5-9b759591a493'
+    # uuid -v5 64d01804-1f83-11ec-987c-7f6caec3998b
+    # 52441596-1f83-11ec-93c5-9b759591a493
+    GROUP_UUID = '2a1be6ea-15b0-5ac1-9d70-643e2ae306cb'
+
+    def test_sanitize_binding_profile_allocation(self):
+        old_format = self.RP_UUID
+        new_format = {self.GROUP_UUID: self.RP_UUID}
+        min_bw_rules = [mock.MagicMock(id=self.MIN_BW_RULE_ID)]
+        self.assertEqual(
+            new_format,
+            converters.convert_to_sanitized_binding_profile_allocation(
+                old_format, self.PORT_ID, min_bw_rules))
+
+        self.assertEqual(
+            new_format,
+            converters.convert_to_sanitized_binding_profile_allocation(
+                new_format, self.PORT_ID, min_bw_rules))
