@@ -16,8 +16,9 @@
 #
 
 import abc
+import argparse
 import contextlib
-import imp
+import importlib
 import inspect
 import os
 from os import path
@@ -26,9 +27,6 @@ import shutil
 import sys
 import tempfile
 
-import argparse
-import six
-
 from oslo_serialization import jsonutils
 
 __version__ = '0.0.2'
@@ -331,13 +329,14 @@ def ordered(obj):
 
 
 def json_primitive(val):
-    if (str(val).count(_MOCK_CLASS_NAME) or
+    if isinstance(val, (str, int, bool)):
+        return str(val)
+    elif str(val).startswith('<') or type(val) in [dict, list, set, tuple]:
+        return str(type(val))
+    elif (str(val).count(_MOCK_CLASS_NAME) or
             str(val).count(_MOCK_IMPORT_CLASS_NAME)):
         return UNKNOWN_VAL
-    primitive = jsonutils.to_primitive(val)
-    if str(primitive).startswith('<'):
-        return UNKNOWN_VAL
-    return primitive
+    return val
 
 
 def is_mock_import(obj):
@@ -695,8 +694,7 @@ class PyLineTokens(object):
     CLOSED_B = ')'
 
 
-@six.add_metaclass(abc.ABCMeta)
-class AbstractFilter(object):
+class AbstractFilter(object, metaclass=abc.ABCMeta):
 
     @abc.abstractmethod
     def mark(self, py_line):
@@ -707,8 +705,7 @@ class AbstractFilter(object):
         pass
 
 
-@six.add_metaclass(abc.ABCMeta)
-class AbstractPerFileFilter(AbstractFilter):
+class AbstractPerFileFilter(AbstractFilter, metaclass=abc.ABCMeta):
 
     def __init__(self):
         self._marked = []
@@ -853,8 +850,7 @@ class RemoveCommentLines(AbstractFilter):
             py_file.del_line(py_line)
 
 
-@six.add_metaclass(abc.ABCMeta)
-class AbstractMultiLineCollector(AbstractFilter):
+class AbstractMultiLineCollector(AbstractFilter, metaclass=abc.ABCMeta):
 
     def __init__(self):
         self._comment_stripper = StripTrailingComments()
@@ -1079,10 +1075,8 @@ class APISignature(object):
         return "%s(%s)" % (signature_dict['qualified_name'], arg_str.strip())
 
     def _build_variable_signature(self, signature_dict):
-        val = (UNKNOWN_VAL
-               if signature_dict['member_value'] is None
-               else signature_dict['member_value'])
-        return "%s = %s" % (signature_dict['qualified_name'], val)
+        return "%s = %s" % (signature_dict['qualified_name'],
+                            signature_dict['member_value'])
 
     def _build_class_signature(self, signature_dict):
         return signature_dict['qualified_name']
@@ -1145,7 +1139,7 @@ class ModuleParser(object):
             if defined_name in sys.modules:
                 del sys.modules[defined_name]
             f, p, d = imp.find_module(module_name, search_paths)
-            module = imp.load_module(defined_name, f, p, d)
+            module = importlib.load_module(defined_name, f, p, d)
             if defined_name == '__init__':
                 setattr(module, '__path__', search_paths)
             return module
@@ -1198,11 +1192,11 @@ class ModuleParser(object):
                 elif inspect.isfunction(member):
                     self._notify(APISignature.SignatureType.FUNCTION,
                                  fqn, member,
-                                 arg_spec=inspect.getargspec(member))
+                                 arg_spec=inspect.getfullargspec(member))
                 elif inspect.ismethod(member):
                     self._notify(APISignature.SignatureType.METHOD,
                                  fqn, member,
-                                 arg_spec=inspect.getargspec(member))
+                                 arg_spec=inspect.getfullargspec(member))
                 else:
                     event = (APISignature.SignatureType.MODULE_ATTR
                              if inspect.ismodule(module)
@@ -1305,6 +1299,11 @@ class APIReport(object):
                               if ordered(self.api[k]) !=
                               ordered(other_api.api[k])]
 
+        for k in common_key_changes:
+            if (not blacklist_filter(self.api[k]['member_value']) and not
+                    blacklist_filter(other_api.api[k]['member_value'])):
+                common_key_changes.remove(k)
+
         def _build_report(new_api):
             apis = APIReport()
             apis._api = new_api
@@ -1325,8 +1324,7 @@ class APIReport(object):
         }
 
 
-@six.add_metaclass(abc.ABCMeta)
-class AbstractCommand(object):
+class AbstractCommand(object, metaclass=abc.ABCMeta):
 
     @abc.abstractmethod
     def get_parser(self):
@@ -1467,6 +1465,23 @@ class DiffReportCommand(AbstractCommand):
 
         new_sigs = api_diff['new_changed'].get_filtered_signatures()
         old_sigs = api_diff['old_changed'].get_filtered_signatures()
+        if len(new_sigs) != len(old_sigs):
+            new_sigs = []
+            old_sigs = []
+            new_changed = api_diff['new_changed'].api
+            old_changed = api_diff['old_changed'].api
+            for n, new_spec in new_changed.items():
+                display_old = blacklist_filter(old_changed[n]['member_value'])
+                display_new = blacklist_filter(new_spec['member_value'])
+                if display_old and display_new:
+                    new_sigs.append(APISignature.get_signature(new_spec))
+                    old_sigs.append(APISignature.get_signature(old_changed[n]))
+                elif not display_old:
+                    new_sigs.append(APISignature.get_signature(new_spec))
+                    old_sigs.append(n)
+                else:
+                    new_sigs.append('UNKNOWN')
+                    old_sigs.append(n)
         self._print_row("Changed API Signatures",
                         ["%s [is now] %s" %
                          (old_sigs[i], new_sigs[i])
